git.delta.rocks / unique-network / refs/commits / 50312582bbed

difftreelog

Fix feature foreign_assets misspels

Ilja Khabarov2022-08-22parent: #55191cf.patch.diff
in: master

5 files changed

modifiedruntime/common/config/pallets/mod.rsdiffbeforeafterboth
40#[cfg(feature = "scheduler")]40#[cfg(feature = "scheduler")]
41pub mod scheduler;41pub mod scheduler;
4242
43#[cfg(feature = "foreign-asset")]43#[cfg(feature = "foreign-assets")]
44pub mod foreign_asset;44pub mod foreign_asset;
4545
46parameter_types! {46parameter_types! {
modifiedruntime/common/config/xcm.rsdiffbeforeafterboth
--- a/runtime/common/config/xcm.rs
+++ b/runtime/common/config/xcm.rs
@@ -40,9 +40,10 @@
 	FixedWeightBounds, FungiblesAdapter, LocationInverter, NativeAsset, ParentAsSuperuser, RelayChainAsNative,
 	SiblingParachainAsNative, SiblingParachainConvertsVia, SignedAccountId32AsNative,
 	SignedToAccountId32, SovereignSignedViaLocation, TakeWeightCredit, ParentIsPreset,
+	ConvertedConcreteAssetId
 };
 use xcm_executor::{Config, XcmExecutor, Assets};
-use xcm_executor::traits::{Convert as ConvertXcm, MatchesFungible, WeightTrader, FilterAssetLocation};
+use xcm_executor::traits::{Convert as ConvertXcm, JustTry, MatchesFungible, WeightTrader, FilterAssetLocation};
 use pallet_foreing_assets::{
 	AssetIds, AssetIdMapping, XcmForeignAssetIdMapping, CurrencyId, NativeCurrency,
 	UsingAnyCurrencyComponents, TryAsForeing, ForeignAssetId,
@@ -356,9 +357,10 @@
 /// Means for transacting assets on this chain.
 #[cfg(feature = "foreign-assets")]
 pub type AssetTransactors = FungiblesTransactor;
-#[cfg(not(feature = "foreign-assets"))]
-pub type AssetTransactors = LocalAssetTransactor;
 
+//#[cfg(not(feature = "foreign-assets"))]
+//pub type AssetTransactors = LocalAssetTransactor;
+
 #[cfg(feature = "foreign-assets")]
 pub struct AllAsset;
 #[cfg(feature = "foreign-assets")]
@@ -370,14 +372,15 @@
 
 #[cfg(feature = "foreign-assets")]
 pub type IsReserve = AllAsset;
-#[cfg(not(feature = "foreign-assets"))]
-pub type IsReserve = NativeAsset;
+//#[cfg(not(feature = "foreign-assets"))]
+//pub type IsReserve = NativeAsset;
 
 #[cfg(feature = "foreign-assets")]
 type Trader<T> =
 	UsingAnyCurrencyComponents<
 		pallet_configuration::WeightToFee<T, Balance>,
 		RelayLocation, AccountId, Balances, ()>;
+/*
 #[cfg(not(feature = "foreign-assets"))]
 type Trader<T> = UsingOnlySelfCurrencyComponents<
 	pallet_configuration::WeightToFee<T, Balance>,
@@ -386,6 +389,7 @@
 	Balances,
 	(),
 >;
+*/
 
 pub struct XcmConfig<T>(PhantomData<T>);
 impl<T> Config for XcmConfig<T>
modifiedruntime/opal/Cargo.tomldiffbeforeafterboth
--- a/runtime/opal/Cargo.toml
+++ b/runtime/opal/Cargo.toml
@@ -126,12 +126,12 @@
     "pallet-foreing-assets/std"
 ]
 limit-testing = ['pallet-unique/limit-testing', 'up-data-structs/limit-testing']
-opal-runtime = ['refungible', 'scheduler', 'rmrk', 'foreign-asset']
+opal-runtime = ['refungible', 'scheduler', 'rmrk', 'foreign-assets']
 
 refungible = []
 scheduler = []
 rmrk = []
-foreign-asset = []
+foreign-assets = []
 
 ################################################################################
 # Substrate Dependencies
modifiedtests/package.jsondiffbeforeafterboth
--- a/tests/package.json
+++ b/tests/package.json
@@ -75,6 +75,10 @@
     "testScheduler": "mocha --timeout 9999999 -r ts-node/register ./**/scheduler.test.ts",
     "testSchedulingEVM": "mocha --timeout 9999999 -r ts-node/register ./**/eth/scheduling.test.ts",
     "testXcmTransfer": "mocha --timeout 9999999 -r ts-node/register ./**/xcmTransfer.test.ts",
+    "testXcmTransferAcala": "mocha --timeout 9999999 -r ts-node/register ./**/xcmTransferAcala.test.ts",
+    "testXcmTransferKarura": "mocha --timeout 9999999 -r ts-node/register ./**/xcmTransferKarura.test.ts",
+    "testXcmTransferStatemine": "mocha --timeout 9999999 -r ts-node/register ./**/xcmTransferStatemine.test.ts",
+    "testXcmTransferMoonriver": "mocha --timeout 9999999 -r ts-node/register ./**/xcmTransferMoonriver.test.ts",
     "testPalletPresence": "mocha --timeout 9999999 -r ts-node/register ./**/pallet-presence.test.ts",
     "testBlockProduction": "mocha --timeout 9999999 -r ts-node/register ./**/block-production.test.ts",
     "testEnableDisableTransfers": "mocha --timeout 9999999 -r ts-node/register ./**/enableDisableTransfer.test.ts",
modifiedtests/src/xcmTransferStatemine.test.tsdiffbeforeafterboth
--- a/tests/src/xcmTransferStatemine.test.ts
+++ b/tests/src/xcmTransferStatemine.test.ts
@@ -30,7 +30,7 @@
 const expect = chai.expect;
 
 const RELAY_PORT = '9844';
-const UNIQUE_CHAIN = 5000;
+const UNIQUE_CHAIN = 2037;
 const UNIQUE_PORT = '9944';
 const STATEMINE_CHAIN = 1000;
 const STATEMINE_PORT = '9946';
@@ -87,8 +87,9 @@
       const result3 = getGenericResult(events3);
       expect(result3.success).to.be.true;
 
-      // funding parachain sovereing account (Parachain: 5000)
-      const parachainSovereingAccount = '0x7369626c88130000000000000000000000000000000000000000000000000000';
+      // funding parachain sovereing account (Parachain: 2037)
+      //const parachainSovereingAccount = '0x70617261f5070000000000000000000000000000000000000000000000000000';
+      const parachainSovereingAccount = '0x7369626cf5070000000000000000000000000000000000000000000000000000';
       const tx4 = api.tx.balances.transfer(parachainSovereingAccount, fundingAmount);
       const events4 = await submitTransactionAsync(bob, tx4);
       const result4 = getGenericResult(events4);
@@ -265,7 +266,7 @@
     }, uniqueApiOptions);
   });
 
-  it('Should connect and send USDT from Unique to Statemine back', async () => {
+  it.skip('Should connect and send USDT from Unique to Statemine back', async () => {
     let balanceBefore: bigint;
     const uniqueApiOptions: ApiOptions = {
       provider: new WsProvider('ws://127.0.0.1:' + UNIQUE_PORT),